==> casemeta-0.3.0-py3-none-any.whl: casemeta/__main__.py <==
from casemeta.ponencia.slice import slice_ponencia

from .annex import create_dividing_attributes, get_annex
from .field import construct_body, spot_category, spot_composition, spot_writer
from .ponencia import mark_positions, slice_ponencia


def meta(raw: str, initial_text: str):
    """
    Given raw text, generate dictionary of:
    1. Ponente: name of writer of text
    2. Category: whether the text is a Decision or a Resolution
    3. Composition: whether the Court sits as a Division or En Banc
    4. Ponencia: the body of the text
    5. Annex: the portion of the text consisting of footnotes
    6. Fallo: the dispositive portion of the text
    7. Voting: participation of justices in the text
    8. Ruling: the explanation for the fallo
    9. Ruling marker: the textual start of the ruling
    10. Ruling offset: the index of the ruling marker
    """

    # from the raw text, sanitize content
    body = construct_body(raw)

    # get the raw writer, raw category as a start string to slice ponencia
    raw_writer, ponente = spot_writer(body)
    raw_category, category = spot_category(body)

    # mark body with attributes for use in ponencia / annex slicing
    marked_body = create_dividing_attributes(body)

    # create meta data based on preliminary fields
    data = {
        "initial": initial_text,
        "ponente": ponente,
        "category": category,
        "composition": spot_composition(body),
        "annex": get_annex(marked_body),
    }

    # other fields to add to the dictionary
    keys = [
        "fallo",
        "voting",
        "ruling",
        "ruling_marker",
        "ruling_offset",
        "ponencia",
    ]

    # temp ponencia includes fallo, voting clauses
    temp = slice_ponencia(marked_body, raw_writer or raw_category)

    # from temp, get more specific fields and slice ponencia further
    if (fields := mark_positions(temp)) :
        data.update({k: v for (k, v) in fields.items() if k in keys})

    return data

==> casemeta-0.4.0-py3-none-any.whl: casemeta/__main__.py <==
from casemeta.ponencia.slice import slice_ponencia

from .annex import create_dividing_attributes, get_annex
from .field import construct_body, spot_category, spot_composition, spot_writer
from .ponencia import capture_values, slice_ponencia


def meta(raw: str, initial_text: str):
    """
    Given raw text, generate dictionary of:
    1. Ponente: name of writer of text
    2. Category: whether the text is a Decision or a Resolution
    3. Composition: whether the Court sits as a Division or En Banc
    4. Ponencia: the body of the text
    5. Annex: the portion of the text consisting of footnotes
    6. Fallo: the dispositive portion of the text
    7. Voting: participation of justices in the text
    8. Ruling: the explanation for the fallo
    9. Ruling marker: the textual start of the ruling
    10. Ruling offset: the index of the ruling marker
    """
    body = construct_body(raw)  # sanitize content
    raw_W, ponente = spot_writer(body)
    raw_C, category = spot_category(body)
    start_slice = raw_W or raw_C  # use writer as start; else use category
    marked_body = create_dividing_attributes(body)  # ponencia / annex slicing
    data = {  # preliminary fields
        "initial": initial_text,
        "ponente": ponente,
        "category": category,
        "composition": spot_composition(body),
        "annex": get_annex(marked_body),
    }
    keys = [  # detailed fields to mark
        "fallo",
        "voting",
        "ruling",
        "ruling_marker",
        "ruling_offset",
        "ponencia",  # 'pon' includes fallo / voting; 'ponencia' culls these
        "error",
    ]
    pon = slice_ponencia(marked_body, start_slice)
    data.update({k: v for (k, v) in capture_values(pon).items() if k in keys})
    return data
